@@ -4,14 +4,14 @@
 #define CALAMARES_VERSION_H
 
 #define CALAMARES_ORGANIZATION_NAME "Calamares"
-#define CALAMARES_ORGANIZATION_DOMAIN "github.com/calamares"
+#define CALAMARES_ORGANIZATION_DOMAIN "calamares.io"
 #define CALAMARES_APPLICATION_NAME "Calamares"
-#define CALAMARES_VERSION "3.3.14"
-#define CALAMARES_VERSION_SHORT "3.3.14"
+#define CALAMARES_VERSION "3.4.0"
+#define CALAMARES_VERSION_SHORT "3.4.0"
 
 #define CALAMARES_VERSION_MAJOR "3"
-#define CALAMARES_VERSION_MINOR "3"
-#define CALAMARES_VERSION_PATCH "14"
+#define CALAMARES_VERSION_MINOR "4"
+/* #undef CALAMARES_VERSION_PATCH */
 /* #undef CALAMARES_VERSION_RC */
 
 #endif  // CALAMARES_VERSION_H
